==> earth_2.1-2.tar.gz: earth/R/print.earth.R <==
# print.earth.R: functions for summarizing and printing earth objects

# print.earth's 1st arg is actually an obj but called x for consistency with generic

print.earth <- function(x, print.glm=TRUE, digits=getOption("digits"), fixed.point=TRUE, ...)
{

    form <- function(x, pad)
    {
        sprintf("%-*s", digits+pad,
                format(if(abs(x) < 1e-20) 0 else x, digits=digits))
    }

    warn.if.dots.used("print.earth", ...)
    check.classname(x, deparse(substitute(x)), "earth")
    if(is.null(x$glm.list))     # glm.list is a list of glm models, null if none
        cat("Selected ")
    else
        cat("Earth selected ")  # remind user that these are for the earth not glm model

    cat(length(x$selected.terms), "of", nrow(x$dirs), "terms, and",
        get.nused.preds.per.subset(x$dirs, x$selected.terms),
        "of", ncol(x$dirs), "predictors ")

    nlinpreds <- sum(x$dirs[x$selected.terms,] == 2)
    if(nlinpreds == 1)
        cat(nlinpreds, " linear predictor", sep="")
    else if(nlinpreds > 1)
        cat(nlinpreds, " linear predictors", sep="")
    cat("\n")

    print.one.line.evimp(x) # print estmated var importances on a single line

    nterms.per.degree <- get.nterms.per.degree(x, x$selected.terms)
    cat("Number of terms at each degree of interaction:", nterms.per.degree)

    cat(switch(length(nterms.per.degree),
            " (intercept only model)",
            " (additive model)"),
        "\n", sep="")

    nresp <- NCOL(x$coefficients)

    if(nresp > 1) {
        # create a matrix and print that

        a <- matrix(nrow=nresp+1, ncol=4)
        rownames(a) <- c(colnames(x$fitted.values), "All")
        colnames(a) <- c("GCV", "RSS", "GRSq", "RSq")
        for(iresp in 1:nresp)
             a[iresp,] <- c(x$gcv.per.response[iresp],
                            x$rss.per.response[iresp],
                            x$grsq.per.response[iresp],
                            x$rsq.per.response[iresp])

        a[nresp+1,] <- c(x$gcv, x$rss, x$grsq, x$rsq)  # final row for "All"
        cat("\n")
        if(!is.null(x$glm.list))
            cat("earth\n") # remind user
        if(fixed.point)
           a <- my.fixed.point(a, digits)
        print(a, digits=digits)
    } else {
        if(!is.null(x$glm.list))
            cat("earth ")   # remind user
        cat("GCV ",   format(x$gcv,  digits=digits),
            "    RSS ",  format(x$rss,  digits=digits),
            "    GRSq ", format(x$grsq, digits=digits),
            "    RSq ",  format(x$rsq,  digits=digits),
            "\n", sep="")
    }
    if(print.glm && !is.null(x$glm.list))
        print.earth.glm(x, digits, fixed.point)

    invisible(x)
}

# The first arg is actually an object but called x for consistency with generic

print.summary.earth <- function(
    x           = stop("no 'x' arg"),     # "summary.earth" object
    details     = x$details,
    decomp      = x$decomp,
    digits      = x$digits,
    fixed.point = x$fixed.point,
    ...)
{
    my.print.call("Call: ", x$call)
    nresp <- NCOL(x$coefficients)
        cat("\n")
    warn.if.dots.used("print.summary.earth", ...)
    is.glm.model <- !is.null(x$glm.list)   # TRUE if embedded GLM model(s)
    new.order <- reorder.earth(x, decomp=decomp)
    response.names <- colnames(x$coeff)

    # print coefficients

    if(!is.glm.model || details) {
        if(!is.null(x$strings)) {      # old style expression formatting?
                        for(iresp in 1:nresp) {
                                   cat(response.names[iresp], " =\n", sep="")
                                   cat(x$strings[iresp])
                                   cat("\n")
           }
        } else {
            rownames(x$coefficients) <- spaceout(rownames(x$coefficients))
            coef <- x$coefficients[new.order, , drop=FALSE]
            if(fixed.point)
                coef <- my.fixed.point(coef, digits)
            if(is.glm.model)
                cat("earth coefficients\n") # remind user what these are
                        else if(nresp == 1)
                colnames(coef) = "coefficients"
            print(coef, digits=digits)
            cat("\n")
        }
    }
    if(is.glm.model) {
        if(!is.null(x$strings)) {      # old style expression formatting?
           for(iresp in 1:nresp) {
               g <- x$glm.list[[iresp]]
               cat("GLM ")
               cat(response.names[iresp], " =\n", sep="")
               cat(x$strings[nresp+iresp]) # glm strings index is offset by nresp
               cat("\n")
           }
        } else {
            cat("GLM coefficients\n")
            rownames(x$glm.coefficients) <- spaceout(rownames(x$glm.coefficients))
            coef <- x$glm.coefficients[new.order, , drop=FALSE]
            if(fixed.point)
                coef <- my.fixed.point(coef, digits)
            print(coef, digits=digits)
            cat("\n")
        }
        if(details) for(iresp in 1:nresp)
           print.glm.details(x$glm.list[[iresp]], nresp, digits, my.fixed.point, response.names[iresp])
    }
    if(details)
        cat("Number of cases: ", nrow(x$residuals), "\n", sep="")
    print.earth(x, digits, print.glm=FALSE)
    if(!is.null(x$glm.list))
        print.earth.glm(x, digits, fixed.point)
    invisible(x)
}

# put some spaces into term names for readability
#     convert h(x1-5860)*h(x2--15)
#     to      h(x1-5860) * h(x2- -15)

spaceout <- function(rownames.)
{
    rownames. <- gsub("\\*", " * ", rownames.)   # spaces around *
    rownames. <- gsub("--", "- -", rownames.)    # spaces between --
    gsub("`", "", rownames.)                     # remove backquotes
}

summary.earth <- function(   # returns a superset, not a summary in the strict sense
    object  = stop("no 'object' arg"),
    details = FALSE,
    decomp  = "anova",        # see reorder.earth for legal decomp values
    style   = c("h", "pmax", "bf"), # use "pmax" for old earth style earth expression formatting
    digits  = getOption("digits"),
    fixed.point = TRUE,       # see help page
    ...)                      # extra args passed on to format.earth
{
    rval <- object
    switch(match.arg1(style),
        NULL,                                                                              # "h"
        rval$strings <- format.earth(x=object, digits=digits, decomp=decomp, style=style), # "pmax"
        rval$strings <- format.earth(x=object, digits=digits, decomp=decomp, style=style)) # "bf"
    rval$details     <- details  # ditto
    rval$decomp      <- decomp
    rval$digits      <- digits   # allows us to pass digits arg on to print.summary.earth
    rval$fixed.point <- fixed.point
    class(rval)      <- c("summary.earth", "earth")
    rval
}

==> earth_2.2-1.tar.gz: earth/R/print.earth.R <==
# print.earth.R: functions for summarizing and printing earth objects

# print.earth's 1st arg is actually an obj but called x for consistency with generic

print.earth <- function(x, print.glm=TRUE, digits=getOption("digits"), fixed.point=TRUE, ...)
{
    form <- function(x, pad)
    {
        sprintf("%-*s", digits+pad,
                format(if(abs(x) < 1e-20) 0 else x, digits=digits))
    }

    warn.if.dots.used("print.earth", ...)
    check.classname(x, deparse(substitute(x)), "earth")
    if(is.null(x$glm.list))     # glm.list is a list of glm models, null if none
        cat("Selected ")
    else
        cat("Earth selected ")  # remind user that these are for the earth not glm model

    cat(length(x$selected.terms), "of", nrow(x$dirs), "terms, and",
        get.nused.preds.per.subset(x$dirs, x$selected.terms),
        "of", ncol(x$dirs), "predictors ")

    nlinpreds <- sum(x$dirs[x$selected.terms,] == 2)
    if(nlinpreds == 1)
        cat(nlinpreds, " linear predictor", sep="")
    else if(nlinpreds > 1)
        cat(nlinpreds, " linear predictors", sep="")
    cat("\n")

    print.one.line.evimp(x) # print estimated var importances on a single line

    nterms.per.degree <- get.nterms.per.degree(x, x$selected.terms)
    cat("Number of terms at each degree of interaction:", nterms.per.degree)

    cat(switch(length(nterms.per.degree),
            " (intercept only model)",
            " (additive model)"),
        "\n", sep="")

    nresp <- NCOL(x$coefficients)
    is.cv <- !is.null(x$cv.list)
    ilast <- nrow(x$cv.rsq.tab)

    if(nresp > 1) {
        # create a matrix and print that

        a <- matrix(nrow=nresp+1, ncol=4 + is.cv)
        rownames(a) <- c(colnames(x$fitted.values), "All")
        colnames. <- c("GCV", "RSS", "GRSq", "RSq")
        if(is.cv)
            colnames. <- c(colnames., "CV-RSq")
        colnames(a) <- colnames.
        for(iresp in 1:nresp) {
            a[iresp,1:4] <- c(x$gcv.per.response[iresp],
                              x$rss.per.response[iresp],
                              x$grsq.per.response[iresp],
                              x$rsq.per.response[iresp])
            if(is.cv)
                a[iresp,5] <- x$cv.rsq.tab[ilast,iresp]
        }
        # final row for "All"
        a[nresp+1,1:4] <- c(x$gcv, x$rss, x$grsq, x$rsq)
        if(is.cv)
            a[nresp+1,5] <- x$cv.rsq.tab[ilast,ncol(x$cv.rsq.tab)]
        cat("\n")
        if(!is.null(x$glm.list))
            cat("Earth\n") # remind user
        if(fixed.point)
           a <- my.fixed.point(a, digits)
        print(a, digits=digits)
    } else {
        if(!is.null(x$glm.list))
            cat("Earth ")   # remind user
        cat("GCV ",   format(x$gcv,  digits=digits),
            "    RSS ",  format(x$rss,  digits=digits),
            "    GRSq ", format(x$grsq, digits=digits),
            "    RSq ",  format(x$rsq,  digits=digits), sep="")
        if(is.cv)
            cat("    CV-RSq ",
                format(x$cv.rsq.tab[ilast,1], digits=digits), sep="")
        cat("\n")
    }
    if(print.glm && !is.null(x$glm.list))
        print.earth.glm(x, digits, fixed.point)

    invisible(x)
}

# The first arg is actually an object but called x for consistency with generic

print.summary.earth <- function(
    x           = stop("no 'x' arg"),     # "summary.earth" object
    details     = x$details,
    decomp      = x$decomp,
    digits      = x$digits,
    fixed.point = x$fixed.point,
    ...)
{
    my.print.call("Call: ", x$call)
    nresp <- NCOL(x$coefficients)
        cat("\n")
    warn.if.dots.used("print.summary.earth", ...)
    is.glm <- !is.null(x$glm.list)   # TRUE if embedded GLM model(s)
    new.order <- reorder.earth(x, decomp=decomp)
    response.names <- colnames(x$fitted.values)

    # print coefficients

    if(!is.glm || details) {
        if(!is.null(x$strings)) {      # old style expression formatting?
            for(iresp in 1:nresp) {
                cat(response.names[iresp], " =\n", sep="")
                cat(x$strings[iresp])
                cat("\n")
           }
        } else {
            rownames(x$coefficients) <- spaceout(rownames(x$coefficients))
            coef <- x$coefficients[new.order, , drop=FALSE]
            if(fixed.point)
                coef <- my.fixed.point(coef, digits)
            if(is.glm)
                cat("Earth coefficients\n") # remind user what these are
                        else if(nresp == 1)
                colnames(coef) = "coefficients"
            print(coef, digits=digits)
            cat("\n")
        }
    }
    if(is.glm) {
        if(!is.null(x$strings)) {      # old style expression formatting?
           for(iresp in 1:nresp) {
               g <- x$glm.list[[iresp]]
               cat("GLM ")
               cat(response.names[iresp], " =\n", sep="")
               cat(x$strings[nresp+iresp]) # glm strings index is offset by nresp
               cat("\n")
           }
        } else {
            cat("GLM coefficients\n")
            rownames(x$glm.coefficients) <- spaceout(rownames(x$glm.coefficients))
            coef <- x$glm.coefficients[new.order, , drop=FALSE]
            if(fixed.point)
                coef <- my.fixed.point(coef, digits)
            print(coef, digits=digits)
            cat("\n")
        }
        if(details) for(iresp in 1:nresp)
           print.glm.details(x$glm.list[[iresp]], nresp, digits, 
                             my.fixed.point, response.names[iresp])
    }
    if(details)
        cat("Number of cases: ", nrow(x$residuals), "\n", sep="")
    print.earth(x, digits, print.glm=FALSE)
    if(!is.null(x$glm.list))
        print.earth.glm(x, digits, fixed.point)
    if(!is.null(x$cv.list))
        print.cv(x)
    invisible(x)
}

# put some spaces into term names for readability
#     convert h(x1-5860)*h(x2--15)
#     to      h(x1-5860) * h(x2- -15)

spaceout <- function(rownames.)
{
    rownames. <- gsub("\\*", " * ", rownames.)   # spaces around *
    rownames. <- gsub("--", "- -", rownames.)    # spaces between --
    gsub("`", "", rownames.)                     # remove backquotes
}

summary.earth <- function(   # returns a superset, not a summary in the strict sense
    object  = stop("no 'object' arg"),
    details = FALSE,
    decomp  = "anova",        # see reorder.earth for legal decomp values
    style   = c("h", "pmax", "bf"), # use "pmax" for old earth style earth expression formatting
    digits  = getOption("digits"),
    fixed.point = TRUE,       # see help page
    ...)                      # extra args passed on to format.earth
{
    rval <- object
    switch(match.arg1(style),
        NULL,                                                                              # "h"
        rval$strings <- format.earth(x=object, digits=digits, decomp=decomp, style=style), # "pmax"
        rval$strings <- format.earth(x=object, digits=digits, decomp=decomp, style=style)) # "bf"
    rval$details     <- details  # ditto
    rval$decomp      <- decomp
    rval$digits      <- digits   # allows us to pass digits arg on to print.summary.earth
    rval$fixed.point <- fixed.point
    class(rval)      <- c("summary.earth", "earth")
    rval
}
